============
Contributors
============

atomate development is led by the Hacking Materials research group led by Anubhav Jain at Lawrence Berkeley National Lab, using research funding from U.S. Deparment of Energy Early Career program.

Major contributions are provided by:

* The Materials Virtual Lab research group of Prof. Shyue Ping Ong at UC San Diego.
* Kiran Mathew, Shyam Dwaraknath, Joey Montoya, and Murat Aykol through the research group of Prof. Kristin Persson at UC Berkeley.

Minor contributions are provided by:

* Alireza Faghaninia
